@@ -1,4 +1,4 @@
-from sdccli.client_v3.monitor import SdMonitorClient
+from sdcclient import SdMonitorClient
 
 
 def retrieve_team_by_name_or_id(monitor: SdMonitorClient, team):
